==> piwigo-2.1.6.zip: piwigo/plugins/LocalFilesEditor/language/ru_RU/plugin.lang.php <==
<?php
// +-----------------------------------------------------------------------+
// | Piwigo - a PHP based picture gallery                                  |
// +-----------------------------------------------------------------------+
// | Copyright(C) 2008-2010 Piwigo Team                  http://piwigo.org |
// | Copyright(C) 2003-2008 PhpWebGallery Team    http://phpwebgallery.net |
// | Copyright(C) 2002-2003 Pierrick LE GALL   http://le-gall.net/pierrick |
// +-----------------------------------------------------------------------+
// | This program is free software; you can redistribute it and/or modify  |
// | it under the terms of the GNU General Public License as published by  |
// | the Free Software Foundation                                          |
// |                                                                       |
// | This program is distributed in the hope that it will be useful, but   |
// | WITHOUT ANY WARRANTY; without even the implied warranty of            |
// | MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU      |
// | General Public License for more details.                              |
// |                                                                       |
// | You should have received a copy of the GNU General Public License     |
// | along with this program; if not, write to the Free Software           |
// | Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, |
// | USA.                                                                  |
// +-----------------------------------------------------------------------+

$lang['locfiledit_onglet_localconf'] = 'Локальные настройки';
$lang['locfiledit_onglet_css'] = 'CSS';
$lang['locfiledit_onglet_tpl'] = 'Шаблоны';
$lang['locfiledit_onglet_lang'] = 'Языки';
$lang['locfiledit_onglet_plug'] = 'Личный плагин';
$lang['locfiledit_cant_save'] = 'Текущий файл не может быть записан. Проверьте, имеются ли права зависи в директории  "local/" (chmod).';
$lang['locfiledit_newfile'] = 'Файл не существует и будет создан LocalFilesEditor';
$lang['locfiledit_save_config'] = 'Файл записан успешно';
$lang['locfiledit_show_default'] = 'Показать исходный файл: ';
$lang['locfiledit_save_bak'] = 'Резервная копия файла будет создана при сохранении.';
$lang['locfiledit_saved_bak'] = 'Резервный файл создан (%s)';
$lang['locfiledit_save_file'] = 'Сохранить файл';
$lang['locfiledit_choose_file'] = 'Выберите файл для редактирования';
$lang['locfiledit_edit'] = 'Редактировать';
$lang['locfiledit_restore'] = 'Восстановить резервный файл';
$lang['locfiledit_restore_confirm'] = 'Пожалуйста, подтвердите действие. Восстановленный файл не будет активен до тех пор, пока не будет сохранен.';
$lang['locfiledit_bak_loaded1'] = 'Резервный файл загружен.';
$lang['locfiledit_bak_loaded2'] = 'Вы должны сохранить файл, чтобы восстановить его.';
$lang['locfiledit_syntax_error'] = 'Синтаксическая ошибка! Невозможно сохранить файл.';
$lang['locfiledit_enable_editarea'] = 'Активировать разметку области редактирования';
$lang['locfiledit_disable_editarea'] = 'Дезактивировать разметку области редактирования';
$lang['locfiledit_new_tpl'] = 'Создать новый файл';
$lang['locfiledit_new_filename'] = 'Имя файла';
$lang['locfiledit_model'] = 'Модель';
$lang['locfiledit_empty_page'] = 'Очистить страницу';
$lang['locfiledit_parent_directory'] = 'Родительская директория';
$lang['locfiledit_filename_error'] = 'Запрещенные символы в имени файла.';
$lang['locfiledit_file_already_exists'] = 'Файл уже существует.';
$lang['locfiledit_model_error'] = 'Выберите модель.';
$lang['locfiledit_empty_filename'] = 'Заполните поле "Имя файла".';
$lang['locfiledit_webmaster_only'] = 'Только вэбмастеры могут создавать или редактировать локальные файлы.';

?>

==> piwigo-2.5.1.zip: piwigo/plugins/LocalFilesEditor/language/ru_RU/plugin.lang.php <==
<?php
// +-----------------------------------------------------------------------+
// | Piwigo - a PHP based photo gallery                                    |
// +-----------------------------------------------------------------------+
// | Copyright(C) 2008-2013 Piwigo Team                  http://piwigo.org |
// | Copyright(C) 2003-2008 PhpWebGallery Team    http://phpwebgallery.net |
// | Copyright(C) 2002-2003 Pierrick LE GALL   http://le-gall.net/pierrick |
// +-----------------------------------------------------------------------+
// | This program is free software; you can redistribute it and/or modify  |
// | it under the terms of the GNU General Public License as published by  |
// | the Free Software Foundation                                          |
// |                                                                       |
// | This program is distributed in the hope that it will be useful, but   |
// | WITHOUT ANY WARRANTY; without even the implied warranty of            |
// | MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU      |
// | General Public License for more details.                              |
// |                                                                       |
// | You should have received a copy of the GNU General Public License     |
// | along with this program; if not, write to the Free Software           |
// | Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, |
// | USA.                                                                  |
// +-----------------------------------------------------------------------+

$lang['locfiledit_onglet_localconf'] = 'Локальные настройки';
$lang['locfiledit_onglet_css'] = 'CSS';
$lang['locfiledit_onglet_tpl'] = 'Шаблоны';
$lang['locfiledit_onglet_lang'] = 'Языки';
$lang['locfiledit_onglet_plug'] = 'Личный плагин';
$lang['locfiledit_cant_save'] = 'Текущий файл не может быть записан. Проверьте, имеются ли права зависи в директории  "local/" (chmod).';
$lang['locfiledit_newfile'] = 'Файл не существует и будет создан LocalFilesEditor';
$lang['locfiledit_save_config'] = 'Файл записан успешно';
$lang['locfiledit_show_default'] = 'Показать исходный файл: ';
$lang['locfiledit_save_bak'] = 'Резервная копия файла будет создана при сохранении.';
$lang['locfiledit_saved_bak'] = 'Резервный файл создан (%s)';
$lang['locfiledit_save_file'] = 'Сохранить файл';
$lang['locfiledit_choose_file'] = 'Выберите файл для редактирования';
$lang['locfiledit_edit'] = 'Редактировать';
$lang['locfiledit_restore'] = 'Восстановить резервный файл';
$lang['locfiledit_restore_confirm'] = 'Пожалуйста, подтвердите действие. Восстановленный файл не будет активен до тех пор, пока не будет сохранен.';
$lang['locfiledit_bak_loaded1'] = 'Резервный файл загружен.';
$lang['locfiledit_bak_loaded2'] = 'Вы должны сохранить файл, чтобы восстановить его.';
$lang['locfiledit_syntax_error'] = 'Синтаксическая ошибка! Невозможно сохранить файл.';
$lang['locfiledit_new_tpl'] = 'Создать новый файл';
$lang['locfiledit_new_filename'] = 'Имя файла';
$lang['locfiledit_model'] = 'Модель';
$lang['locfiledit_empty_page'] = 'Очистить страницу';
$lang['locfiledit_parent_directory'] = 'Родительская директория';
$lang['locfiledit_filename_error'] = 'Запрещенные символы в имени файла.';
$lang['locfiledit_file_already_exists'] = 'Файл уже существует.';
$lang['locfiledit_model_error'] = 'Выберите модель.';
$lang['locfiledit_empty_filename'] = 'Заполните поле "Имя файла".';
$lang['locfiledit_webmaster_only'] = 'Только вэбмастеры могут создавать или редактировать локальные файлы.';
?>
